@@ -4,6 +4,7 @@ use Mesos::Types qw(:all);
 use Type::Params qw(validate);
 use Types::Standard qw(Str);
 use Moo;
+use namespace::autoclean;
 with 'Mesos::Role::HasDispatcher';
 
 =head1 NAME
@@ -12,6 +13,10 @@ Mesos::ExecutorDriver - perl interface to MesosExecutorDriver
 
 =head1 ATTRIBUTES
 
+=head2 autoflush
+
+Enable or disable autoflush for STDOUT. By default autoflush is enabled while the driver is running, and returned to its previous state when the driver has stopped. This is to ensure that STDOUT gets logged in Mesos. Otherwise, perl defaults to using block buffering on STDOUT, and there are no guarantees it will be flushed before the driver shuts down.
+
 =head2 dispatcher
 
 Either a Mesos::Dispatcher instance, or the short name of a dispatcher to instantiate(such as AnyEvent). The short name cannot be used if the dispatcher has required arguments.
@@ -24,6 +29,11 @@ A Mesos::Executor instance
 
 =cut
 
+has autoflush => (
+    is      => 'ro',
+    default => 1,
+);
+
 has executor => (
     is       => 'ro',
     isa      => Executor,
@@ -41,6 +51,16 @@ around sendFrameworkMessage => sub {
     return $self->$orig(validate \@args, Str);
 };
 
+after start => sub {
+    my ($self) = @_;
+    $|++ if $self->autoflush;
+};
+
+before stop => sub {
+    my ($self) = @_;
+    $|-- if $self->autoflush;
+};
+
 sub BUILD {
     my ($self) = @_;
     $self->_xs_init($self->dispatcher);
