@@ -1,10 +1,6 @@
 package Mesos::Test::Executor;
+use Mesos::Messages;
 use Moo;
-use strict;
-use warnings;
-
 extends 'Mesos::Executor';
-with 'Mesos::Test::Role::Process';
-
 
 1;
